# EraLegis

[![Build Status](https://travis-ci.org/tiagocordeiro/eralegis.svg?branch=master)](https://travis-ci.org/tiagocordeiro/eralegis)
[![Updates](https://pyup.io/repos/github/tiagocordeiro/eralegis/shield.svg)](https://pyup.io/repos/github/tiagocordeiro/eralegis/)
[![Python 3](https://pyup.io/repos/github/tiagocordeiro/eralegis/python-3-shield.svg)](https://pyup.io/repos/github/tiagocordeiro/eralegis/)

### Instalando via git
```shell
git clone https://github.com/tiagocordeiro/eralegis.git
```

### Configurando o ambiente
```shell
$ python3 -m venv venv
$ source venv/bin/activate
(venv)$ 
```

### Importando o módulo
```python
$ python
>>> from eralegis import thelemicdate
>>> hoje = thelemicdate.now()
>>> print(hoje)
☉ in 04º ♉ ☽ in 24º ♌ Dies Martis Anno IV:v æræ novæ
```

